//////////////////////////////////////////////////////////////         
//      $Id: rpmutils.h,v 1.2.4.1 2001/03/08 20:52:49 reiher Exp $ 
//
#include "../config.h"
#include <string.h>

/* stupid RPM headers! */
#include <sys/types.h>
typedef __off64_t off64_t;
#include <rpm/rpmlib.h>

int findPackageByLabel(rpmdb db, const char *arg, dbiIndexSet *matches);
int findMatches(rpmdb db, char *name, char *version, char *release,
		dbiIndexSet *matches);

